@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2016/11/20 20:15:53 $
- * $Revision: 1.165 $
+ * $Date: 2019/02/17 19:45:07 $
+ * $Revision: 1.167 $
  */
 
 /*
@@ -69,6 +69,7 @@ CDKVIEWER *newCDKViewer (CDKSCREEN *cdkscreen,
    };
    /* *INDENT-ON* */
 
+
    if ((viewer = newCDKObject (CDKVIEWER, &my_funcs)) == 0)
         return (0);
 
@@ -486,15 +487,22 @@ void cleanCDKViewer (CDKVIEWER *viewer)
    drawCDKViewer (viewer, ObjOf (viewer)->box);
 }
 
-static void PatternNotFound (CDKVIEWER *viewer, char *pattern)
+static void PatternNotFound (CDKVIEWER *viewer, const char *pattern)
 {
-   CDK_CSTRING tempInfo[2];
-   char *temp = (char *)malloc (80 + strlen (pattern));
-   tempInfo[0] = temp;
-   tempInfo[1] = 0;
-   sprintf (temp, "</U/5>Pattern '%s' not found.<!U!5>", pattern);
-   popUpLabel (viewer, tempInfo);
-   free (temp);
+   if (pattern == 0)
+   {
+      PatternNotFound (viewer, "");
+   }
+   else
+   {
+      CDK_CSTRING tempInfo[2];
+      char *temp = (char *)malloc (80 + strlen (pattern));
+      tempInfo[0] = temp;
+      tempInfo[1] = 0;
+      sprintf (temp, "</U/5>Pattern '%s' not found.<!U!5>", pattern);
+      popUpLabel (viewer, tempInfo);
+      free (temp);
+   }
 }
 
 /*
